==> vtigercrm-5.3.0p0.tgz: vtigercrm/modules/CustomView/language/en_us.lang.php <==
<?php 
/********************************************************************************* 
 * The contents of this file are subject to the SugarCRM Public License  
Version 1.1.2 
 * ("License"); You may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at  
http://www.sugarcrm.com/SPL 
 * Software distributed under the License is distributed on an  "AS IS"   
basis, 
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the  
License for 
 * the specific language governing rights and limitations under the License. 
 * The Original Code is:  SugarCRM Open Source 
 * The Initial Developer of the Original Code is SugarCRM, Inc. 
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.; 
 * All Rights Reserved. 
 * Contributor(s): ______________________________________. 
 ********************************************************************************/ 
/********************************************************************************* 
 * $Header$ 
 * Description:  Defines the English language pack for the Account module. 
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc. 
 * All Rights Reserved. 
 * Contributor(s): ______________________________________.. 
 ********************************************************************************/ 
$mod_strings = Array( 
'LBL_MODULE_NAME'=>'Custom View', 
'LBL_STEP_1_TITLE'=>'View Information', 
'LBL_VIEW_NAME'=>'View Name:', 
'LBL_SETDEFAULT'=>'Set as Default', 
'LBL_LIST_IN_METRICS'=>'List in Metrics', 
'LBL_STEP_2_TITLE'=>'Choose Columns', 
'LBL_STEP_3_TITLE'=>'Standard Filters', 
'LBL_STEP_4_TITLE'=>'Advanced Filters', 
'LBL_STEP_5_TITLE'=>'Access Information', 
'LBL_SF_COLUMNS'=>'Column', 
'LBL_SF_STARTDATE'=>'Start Date', 
'LBL_SF_ENDDATE'=>'End Date', 
'LBL_AF_HDR1'=>'Set the search conditions to further restrict the list.', 
'LBL_AF_HDR2'=>'You can use &quot;or&quot; filters by entering multiple  
items in the third column.', 
'LBL_AF_HDR3'=>'You can enter up to 10 items, separated by commas. For  
example: CA, NY, TX, FL searches for CA or NY or TX or FL.', 
'LBL_AF_HDR4'=>'If "Activity Type" is selected, give any one of the  
following values "Call","Meeting" or "Task".', 
 
//strings added for vtiger 5, date format... 
'LBL_NONE'=>'None', 
'View_Name'=>'View_Name', 
'LBL_AND'=>'And', 
'LBL_DATE_FORMAT_CUSTOMVIEW'=>'Y-m-d', 
//Strings added for filter 
'Custom'=>'Custom',
'Previous FY'=>'Previous FY', 
'Current FY'=>'Current FY', 
'Next FY'=>'Next FY', 
'Previous FQ'=>'Previous FQ', 
'Current FQ'=>'Current FQ', 
'Next FQ'=>'Next FQ', 
'Yesterday'=>'Yesterday', 
'Today'=>'Today', 
'Tomorrow'=>'Tomorrow', 
'Last Week'=>'Last Week', 
'Current Week'=>'Current Week', 
'Next Week'=>'Next Week', 
'Last Month'=>'Last Month', 
'Current Month'=>'Current Month', 
'Next Month'=>'Next Month', 
'Last 7 Days'=>'Last 7 Days', 
'Last 30 Days'=>'Last 30 Days', 
'Last 60 Days'=>'Last 60 Days', 
'Last 90 Days'=>'Last 90 Days', 
'Last 120 Days'=>'Last 120 Days', 
'Next 30 Days'=>'Next 30 Days', 
'Next 60 Days'=>'Next 60 Days', 
'Next 90 Days'=>'Next 90 Days', 
'Next 120 Days'=>'Next 120 Days', 
 
'equals'=>'equals', 
'contains'=>'Contains', 
'does not contain'=>'does not contain', 
'less than'=>'less than', 
'greater than'=>'greater than', 
'less or equal'=>'less or equal', 
'greater or equal'=>'greater or equal', 
 
//Strings added to translate field label vtiger_groups 
'Address'=>'Address', 
'Information'=>'Information', 
'Description'=>'Description', 
'Custom Information'=>'Custom Information', 
'- Event Information'=>'- Event Information', 
'- Event Description'=>'- Event Description', 
'- Task Information'=>'- Task Information', 
'- Task Description'=>'- Task Description', 
 
//Strings added for helpdesk module fields 
'Title'=>'Title', 
'Assigned To'=>'Assigned To', 
'Related to'=>'Related to', 
'Priority'=>'Priority', 
'Product Name'=>'Product Name', 
'Severity'=>'Severity', 
'Status'=>'Status', 
'Category'=>'Category', 
'Created Time'=>'Created Time', 
'Modified Time'=>'Modified Time', 
'Attachment'=>'Attachment', 
 
//Strings added for Leads module fields 
'First Name'=>'First Name', 
'Phone'=>'Phone', 
'Last Name'=>'Last Name', 
'Company'=>'Company', 
'Lead Source'=>'Lead Source', 
'Website'=>'Website', 
'Industry'=>'Industry', 
'Lead Status'=>'Lead Status', 
'Annual Revenue'=>'Annual Revenue', 
'Rating'=>'Rating', 
'No Of Employees'=>'No of Employees', 
'Street'=>'Street', 
'Po Box'=>'PO Box', 
'Postal Code'=>'Postal Code', 
'City'=>'City', 
'Country'=>'Country', 
'State'=>'State', 
 
//Strings added for Accounts module fields 
'Account Name'=>'Account Name', 
'Ticker Symbol'=>'Ticker Symbol', 
'Other Phone'=>'Other Phone', 
'Member Of'=>'Member Of', 
'Employees'=>'Employees', 
'Other Email'=>'Other Email', 
'Ownership'=>'Ownership', 
'industry'=>'industry', 
'SIC Code'=>'SIC Code', 
'Email Opt Out'=>'Email Opt Out', 
'Billing Address'=>'Billing Address', 
'Shipping Address'=>'Shipping Address', 
'Shipping Po Box'=>'Shipping PO Box', 
'Billing Po Box'=>'Billing PO Box', 
'Billing City'=>'Billing City', 
'Shipping City'=>'Shipping City', 
'Billing State'=>'Billing State', 
'Shipping State'=>'Shipping State', 
'Billing Code'=>'Billing Code', 
'Shipping Code'=>'Shipping Code', 
'Shipping Country'=>'Shipping Country', 
'Billing Country'=>'Billing Country', 
 
 
//Strings added for Contacts module fields 
 
'Office Phone'=>'Office Phone', 
'Home Phone'=>'Home Phone', 
'Birthdate'=>'Birthdate', 
'Reports To'=>'Reports To', 
'Assistant Phone'=>'Assistant Phone', 
'Do Not Call'=>'Do Not Call', 
'Mailing Street'=>'Mailing Street', 
'Other Street'=>'Other Street', 
'Mailing Po Box'=>'Mailing PO Box', 
'Other Po Box'=>'Other PO Box', 
'Mailing City'=>'Mailing City', 
'Other City'=>'Other City', 
'Mailing State'=>'Mailing State', 
'Other State'=>'Other State', 
'Mailing Zip'=>'Mailing Zip', 
'Other Zip'=>'Other Zip', 
'Mailing Country'=>'Mailing Country', 
'Other Country'=>'Other Country', 
 
 
//Strings added for Potential module fields 
 
'Potential Name'=>'Potential Name', 
'Amount'=>'Amount', 
'Expected Close Date'=>'Expected Close Date', 
'Next Step'=>'Next Step', 
'Sales Stage'=>'Sales Stage', 
'Probability'=>'Probability', 
 
 
//Strings added for Quotes module fields 
'Subject'=>'Subject', 
'Quote Stage'=>'Quote Stage', 
'Valid Till'=>'Valid Till', 
'Team'=>'Team', 
'Contact Name'=>'Contact Name', 
'Carrier'=>'Carrier', 
'Shipping'=>'Shipping', 
'Inventory Manager'=>'Inventory Manager', 
 
//Strings added for Sales Orders module fields 
'Customer No'=>'Customer No', 
'Quote Name'=>'Quote Name', 
'Purchase Order'=>'Purchase Order', 
'Due Date'=>'Due Date', 
'Pending'=>'Pending', 
'Sales Commission'=>'Sales Commission', 
'Excise Duty'=>'Excise Duty', 
 
//Strings added for Invoices module fields 
'Sales Order'=>'Sales Order', 
'Invoice Date'=>'Invoice Date', 
 
//Strings added for Product module fields 
'Product Active'=>'Product Active', 
'Product Category'=>'Product Category', 
'Sales Start Date'=>'Sales Start Date', 
'Sales End Date'=>'Sales End Date', 
'Support Start Date'=>'Support Start Date', 
'Support Expiry Date'=>'Support Expiry Date', 
'Vendor Name'=>'Vendor Name', 
'Mfr PartNo'=>'Mfr PartNo', 
'Vendor PartNo'=>'Vendor PartNo', 
 
'Serial No'=>'Serial No', 
'Product Sheet'=>'Product Sheet', 
'GL Account'=>'GL Account', 
 
//Strings added for Price book module fields 
'Price Book Name'=>'Price Book Name', 
'Active'=>'Active', 
 
//Strings added for tasks & events module fields 
'Start Date & Time'=>'Start Date & Time', 
 
//error message 
'Missing required fields'=>'Missing required vtiger_fields', 
//Strings added for campaigns 
'Campaign Name'=>'Campaign Name', 
'Campaign Type'=>'Campaign Type', 
'Product'=>'Product', 
'Campaign Status'=>'Campaign Status', 
'Expected Revenue'=>'Expected Revenue', 
'Budget Cost'=>'Budget Cost', 
'Actual Cost'=>'Actual Cost', 
'Expected Response'=>'Expected Response', 
'Num Sent'=>'Num Sent', 
'Target Audience'=>'Target Audience', 
'TargetSize'=>'TargetSize', 
'Sponsor'=>'Sponsor', 
'Expected Sales Count'=>'Expected Sales Count', 
'Expected Response Count'=>'Expected Response Count', 
'Expected ROI'=>'Expected ROI', 
'Actual Sales Count'=>'Actual Sales Count', 
'Actual Response Count'=>'Actual Response Count', 
'Actual ROI'=>'Actual ROI', 
 
 
 
//Added for customview.tpl 
 
'LBL_Select_a_Column'=>'Select a Column', 
'Missing_required_fields'=>'Missing required fields', 
'Details'=>'Details', 
'New_Custom_View'=>'New Custom view',
'Edit_Custom_View'=>'Edit Custom View', 
'LBL_AF_HDR5'=>'Simple Time Filter allows you to select date based on  
<b>Account Created Time</b> or  <b>Account Modified Time</b>', 
'Select_Duration'=>'Select Duration', 
'Simple_Time_Filter'=>'Simple Time Filter', 
'Start_Date'=>'Start Date', 
'End_Date'=>'End Date', 
'LBL_RULE'=>'RULE',

// Added/Updated for vtiger CRM 5.0.4
'not equal to'=>'Not equal to',
'starts with'=>'Starts with',
'ends with'=>'Ends with',
//'Product Code'=>'Product Code',

// Added after 5.0.4 GA

//Added for Role based Custom filters 
'LBL_SET_AS_PUBLIC'=>'Set as Public ',
'LBL_NEW'=>'New',
'LBL_EDIT'=>'Edit',
'LBL_STATUS_PUBLIC_APPROVE'=>'Approve',
'LBL_STATUS_PUBLIC_DENY'=>'Deny',

'LBL_ADVANCED_FILTER' => 'Rule',
); 
?>

==> vtigercrm-5.4.0.tgz: vtigercrm/modules/CustomView/language/en_us.lang.php <==
<?php 
/********************************************************************************* 
 * The contents of this file are subject to the SugarCRM Public License  
Version 1.1.2 
 * ("License"); You may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at  
http://www.sugarcrm.com/SPL 
 * Software distributed under the License is distributed on an  "AS IS"   
basis, 
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the  
License for 
 * the specific language governing rights and limitations under the License. 
 * The Original Code is:  SugarCRM Open Source 
 * The Initial Developer of the Original Code is SugarCRM, Inc. 
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.; 
 * All Rights Reserved. 
 * Contributor(s): ______________________________________. 
 ********************************************************************************/ 
/********************************************************************************* 
 * $Header$ 
 * Description:  Defines the English language pack for the Custom View.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc. 
 * All Rights Reserved. 
 * Contributor(s): ______________________________________.. 
 ********************************************************************************/ 
$mod_strings = Array( 
'LBL_MODULE_NAME'=>'Custom View', 
'LBL_STEP_1_TITLE'=>'View Information', 
'LBL_VIEW_NAME'=>'View Name:', 
'LBL_SETDEFAULT'=>'Set as Default', 
'LBL_LIST_IN_METRICS'=>'List in Metrics', 
'LBL_STEP_2_TITLE'=>'Choose Columns', 
'LBL_STEP_3_TITLE'=>'Standard Filters', 
'LBL_STEP_4_TITLE'=>'Advanced Filters', 
'LBL_STEP_5_TITLE'=>'Access Information', 
'LBL_SF_COLUMNS'=>'Column', 
'LBL_SF_STARTDATE'=>'Start Date', 
'LBL_SF_ENDDATE'=>'End Date', 
'LBL_AF_HDR1'=>'Set the search conditions to further restrict the list.', 
'LBL_AF_HDR2'=>'You can use &quot;or&quot; filters by entering multiple  
items in the third column.', 
'LBL_AF_HDR3'=>'You can enter up to 10 items, separated by commas. For  
example: CA, NY, TX, FL searches for CA or NY or TX or FL.', 
'LBL_AF_HDR4'=>'If "Activity Type" is selected, give any one of the  
following values "Call","Meeting" or "Task".', 
 
//strings added for vtiger 5, date format... 
'LBL_NONE'=>'None', 
'View_Name'=>'View_Name', 
'LBL_AND'=>'And', 
'LBL_DATE_FORMAT_CUSTOMVIEW'=>'Y-m-d', 
//Strings added for filter 
'Custom'=>'Custom',
'Previous FY'=>'Previous FY', 
'Current FY'=>'Current FY', 
'Next FY'=>'Next FY', 
'Previous FQ'=>'Previous FQ', 
'Current FQ'=>'Current FQ', 
'Next FQ'=>'Next FQ', 
'Yesterday'=>'Yesterday', 
'Today'=>'Today', 
'Tomorrow'=>'Tomorrow', 
'Last Week'=>'Last Week', 
'Current Week'=>'Current Week', 
'Next Week'=>'Next Week', 
'Last Month'=>'Last Month', 
'Current Month'=>'Current Month', 
'Next Month'=>'Next Month', 
'Last 7 Days'=>'Last 7 Days', 
'Last 30 Days'=>'Last 30 Days', 
'Last 60 Days'=>'Last 60 Days', 
'Last 90 Days'=>'Last 90 Days', 
'Last 120 Days'=>'Last 120 Days', 
'Next 30 Days'=>'Next 30 Days', 
'Next 60 Days'=>'Next 60 Days', 
'Next 90 Days'=>'Next 90 Days', 
'Next 120 Days'=>'Next 120 Days', 
 
'equals'=>'equals', 
'contains'=>'Contains', 
'does not contain'=>'does not contain', 
'less than'=>'less than', 
'greater than'=>'greater than', 
'less or equal'=>'less or equal', 
'greater or equal'=>'greater or equal', 
 
//Strings added to translate field label vtiger_groups 
'Address'=>'Address', 
'Information'=>'Information', 
'Description'=>'Description', 
'Custom Information'=>'Custom Information', 
'- Event Information'=>'- Event Information', 
'- Event Description'=>'- Event Description', 
'- Task Information'=>'- Task Information', 
'- Task Description'=>'- Task Description', 
 
//Strings added for helpdesk module fields 
'Title'=>'Title', 
'Assigned To'=>'Assigned To', 
'Related to'=>'Related to', 
'Priority'=>'Priority', 
'Product Name'=>'Product Name', 
'Severity'=>'Severity', 
'Status'=>'Status', 
'Category'=>'Category', 
'Created Time'=>'Created Time', 
'Modified Time'=>'Modified Time', 
'Attachment'=>'Attachment', 
 
//Strings added for Leads module fields 
'First Name'=>'First Name', 
'Phone'=>'Phone', 
'Last Name'=>'Last Name', 
'Company'=>'Company', 
'Lead Source'=>'Lead Source', 
'Website'=>'Website', 
'Industry'=>'Industry', 
'Lead Status'=>'Lead Status', 
'Annual Revenue'=>'Annual Revenue', 
'Rating'=>'Rating', 
'No Of Employees'=>'No of Employees', 
'Street'=>'Street', 
'Po Box'=>'PO Box', 
'Postal Code'=>'Postal Code', 
'City'=>'City', 
'Country'=>'Country', 
'State'=>'State', 
 
//Strings added for Accounts module fields 
'Account Name'=>'Organization Name',
'Ticker Symbol'=>'Ticker Symbol', 
'Other Phone'=>'Other Phone', 
'Member Of'=>'Member Of', 
'Employees'=>'Employees', 
'Other Email'=>'Other Email', 
'Ownership'=>'Ownership', 
'industry'=>'industry', 
'SIC Code'=>'SIC Code', 
'Email Opt Out'=>'Email Opt Out', 
'Billing Address'=>'Billing Address', 
'Shipping Address'=>'Shipping Address', 
'Shipping Po Box'=>'Shipping PO Box', 
'Billing Po Box'=>'Billing PO Box', 
'Billing City'=>'Billing City', 
'Shipping City'=>'Shipping City', 
'Billing State'=>'Billing State', 
'Shipping State'=>'Shipping State', 
'Billing Code'=>'Billing Code', 
'Shipping Code'=>'Shipping Code', 
'Shipping Country'=>'Shipping Country', 
'Billing Country'=>'Billing Country', 
 
 
//Strings added for Contacts module fields 
 
'Office Phone'=>'Office Phone', 
'Home Phone'=>'Home Phone', 
'Birthdate'=>'Birthdate', 
'Reports To'=>'Reports To', 
'Assistant Phone'=>'Assistant Phone', 
'Do Not Call'=>'Do Not Call', 
'Mailing Street'=>'Mailing Street', 
'Other Street'=>'Other Street', 
'Mailing Po Box'=>'Mailing PO Box', 
'Other Po Box'=>'Other PO Box', 
'Mailing City'=>'Mailing City', 
'Other City'=>'Other City', 
'Mailing State'=>'Mailing State', 
'Other State'=>'Other State', 
'Mailing Zip'=>'Mailing Zip', 
'Other Zip'=>'Other Zip', 
'Mailing Country'=>'Mailing Country', 
'Other Country'=>'Other Country', 
 
 
//Strings added for Potential module fields 
 
'Potential Name'=>'Opportunity Name',
'Amount'=>'Amount', 
'Expected Close Date'=>'Expected Close Date', 
'Next Step'=>'Next Step', 
'Sales Stage'=>'Sales Stage', 
'Probability'=>'Probability', 
 
 
//Strings added for Quotes module fields 
'Subject'=>'Subject', 
'Quote Stage'=>'Quote Stage', 
'Valid Till'=>'Valid Till', 
'Team'=>'Team', 
'Contact Name'=>'Contact Name', 
'Carrier'=>'Carrier', 
'Shipping'=>'Shipping', 
'Inventory Manager'=>'Inventory Manager', 
 
//Strings added for Sales Orders module fields 
'Customer No'=>'Customer No', 
'Quote Name'=>'Quote Name', 
'Purchase Order'=>'Purchase Order', 
'Due Date'=>'Due Date', 
'Pending'=>'Pending', 
'Sales Commission'=>'Sales Commission', 
'Excise Duty'=>'Excise Duty', 
 
//Strings added for Invoices module fields 
'Sales Order'=>'Sales Order', 
'Invoice Date'=>'Invoice Date', 
 
//Strings added for Product module fields 
'Product Active'=>'Product Active', 
'Product Category'=>'Product Category', 
'Sales Start Date'=>'Sales Start Date', 
'Sales End Date'=>'Sales End Date', 
'Support Start Date'=>'Support Start Date', 
'Support Expiry Date'=>'Support Expiry Date', 
'Vendor Name'=>'Vendor Name', 
'Mfr PartNo'=>'Mfr PartNo', 
'Vendor PartNo'=>'Vendor PartNo', 
 
'Serial No'=>'Serial No', 
'Product Sheet'=>'Product Sheet', 
'GL Account'=>'GL Organization',
 
//Strings added for Price book module fields 
'Price Book Name'=>'Price Book Name', 
'Active'=>'Active', 
 
//Strings added for tasks & events module fields 
'Start Date & Time'=>'Start Date & Time', 
 
//error message 
'Missing required fields'=>'Missing required vtiger_fields', 
//Strings added for campaigns 
'Campaign Name'=>'Campaign Name', 
'Campaign Type'=>'Campaign Type', 
'Product'=>'Product', 
'Campaign Status'=>'Campaign Status', 
'Expected Revenue'=>'Expected Revenue', 
'Budget Cost'=>'Budget Cost', 
'Actual Cost'=>'Actual Cost', 
'Expected Response'=>'Expected Response', 
'Num Sent'=>'Num Sent', 
'Target Audience'=>'Target Audience', 
'TargetSize'=>'TargetSize', 
'Sponsor'=>'Sponsor', 
'Expected Sales Count'=>'Expected Sales Count', 
'Expected Response Count'=>'Expected Response Count', 
'Expected ROI'=>'Expected ROI', 
'Actual Sales Count'=>'Actual Sales Count', 
'Actual Response Count'=>'Actual Response Count', 
'Actual ROI'=>'Actual ROI', 
 
 
 
//Added for customview.tpl 
 
'LBL_Select_a_Column'=>'Select a Column', 
'Missing_required_fields'=>'Missing required fields', 
'Details'=>'Details', 
'New_Custom_View'=>'New Custom view',
'Edit_Custom_View'=>'Edit Custom View', 
'LBL_AF_HDR5'=>'Simple Time Filter allows you to select date based on  
<b>Organization Created Time</b> or  <b>Organization Modified Time</b>',
'Select_Duration'=>'Select Duration', 
'Simple_Time_Filter'=>'Simple Time Filter', 
'Start_Date'=>'Start Date', 
'End_Date'=>'End Date', 
'LBL_RULE'=>'RULE',

// Added/Updated for vtiger CRM 5.0.4
'not equal to'=>'Not equal to',
'starts with'=>'Starts with',
'ends with'=>'Ends with',
//'Product Code'=>'Product Code',

// Added after 5.0.4 GA

//Added for Role based Custom filters 
'LBL_SET_AS_PUBLIC'=>'Set as Public ',
'LBL_NEW'=>'New',
'LBL_EDIT'=>'Edit',
'LBL_STATUS_PUBLIC_APPROVE'=>'Approve',
'LBL_STATUS_PUBLIC_DENY'=>'Deny',

'LBL_ADVANCED_FILTER' => 'Rule',
); 
?>
